<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace NCSU\Auth\Tests;

use Mockery as m;
use NCSU\Auth\Adapter\MockAuthAdapter;
use NCSU\Auth\AuthService;
use NCSU\Auth\Storage\MemoryStorage;
use NCSU\Auth\Tests\Stubs\AdapterStub;
use PHPUnit\Framework\TestCase;

class AuthServiceTest extends TestCase
{
    /** @test */
    function it_sets_default_implementations_when_none_are_given()
    {
        $service = new AuthService();

        $this->assertNull($service->getAdapter());
        $this->assertInstanceOf('NCSU\Auth\Storage\MemoryStorage', $service->getStorage());
    }

    /** @test */
    function it_stores_and_retrieves_adapter_implementations()
    {
        $service = new AuthService(new AdapterStub(), new MemoryStorage());

        $this->assertInstanceOf('NCSU\Auth\Tests\Stubs\AdapterStub', $service->getAdapter());
        $this->assertInstanceOf('NCSU\Auth\Storage\MemoryStorage', $service->getStorage());
    }

    /** @test */
    function it_can_see_if_a_user_is_authenticated()
    {
        $service = new AuthService(new MockAuthAdapter('cacard'));

        $this->assertTrue($service->isAuthenticated());
    }
}
 